@@ -114,93 +114,6 @@ class NeuroMLHdf5Writer(object):
                 nml_doc0.includes.remove(inc)"""
 
 
-class JSONWriter(object):
-    """
-    Write a NeuroMLDocument to JSON, particularly useful
-    when dealing with lots of ArrayMorphs.
-    """
-
-    @classmethod
-    def __encode_as_json(cls, neuroml_document):
-        neuroml_document = cls.__sanitize_doc(neuroml_document)
-        from jsonpickle import encode as json_encode
-
-        try:
-            # Enable encoding of numpy arrays with recent jsonpickle versions
-            import jsonpickle.ext.numpy as jsonpickle_numpy
-
-            jsonpickle_numpy.register_handlers()
-        except ImportError:
-            pass  # older version of jsonpickle
-        encoded = json_encode(neuroml_document)
-        return encoded
-
-    @classmethod
-    def __sanitize_doc(cls, neuroml_document):
-        """
-        Some operations will need to be performed
-        before the document is JSON-pickleable.
-        """
-
-        for cell in neuroml_document.cells:
-            try:
-                cell.morphology.vertices = cell.morphology.vertices.tolist()
-                cell.morphology.physical_mask = cell.morphology.physical_mask.tolist()
-                cell.morphology.connectivity = cell.morphology.connectivity.tolist()
-            except:
-                pass
-
-        return neuroml_document
-
-    @classmethod
-    def __file_handle(cls, filepath):
-        if isinstance(filepath, string_types):
-            import tables
-
-            fileh = tables.open_file(filepath, mode="w")
-
-    @classmethod
-    def write(cls, neuroml_document, file):
-        if isinstance(file, string_types):
-            fileh = open(file, mode="w")
-        else:
-            fileh = file
-
-        if isinstance(neuroml_document, neuroml.NeuroMLDocument):
-            encoded = cls.__encode_as_json(neuroml_document)
-
-        else:
-            raise NotImplementedError(
-                "Currently you can only serialize NeuroMLDocument type in JSON format"
-            )
-
-        fileh.write(encoded)
-        fileh.close()
-
-    @classmethod
-    def write_to_mongodb(cls, neuroml_document, db, host=None, port=None, id=None):
-        from pymongo import MongoClient
-        import json
-
-        if id == None:
-            id = neuroml_document.id
-
-        if host == None:
-            host = "localhost"
-        if port == None:
-            port = 27017
-
-        client = MongoClient(host, port)
-        db = client[db]
-        collection = db[id]
-
-        if isinstance(neuroml_document, neuroml.NeuroMLDocument):
-            encoded = cls.__encode_as_json(neuroml_document)
-
-        encoded_dict = json.loads(encoded)
-        collection.insert(encoded_dict)
-
-
 class ArrayMorphWriter(object):
     """
     For now just testing a simple method which can write a morphology, not a NeuroMLDocument.
